//****************************************************************************
// Copyright (c) Microsoft Corporation. All rights reserved.
//****************************************************************************
using System;
using System.Configuration;
using System.Web.Configuration;
using System.Diagnostics.CodeAnalysis;
using Microsoft.FxCop.Sdk;


namespace Microsoft.FxCop.Rules.ASP.Security.Configuration
{
    sealed class HttpRuntimeEnableHeaderCheckingShouldBeTrue : SystemWebConfigurationIntrospectionRule
    {
        #region *** Constructor ***
        public HttpRuntimeEnableHeaderCheckingShouldBeTrue()
            : base(typeof(HttpRuntimeEnableHeaderCheckingShouldBeTrue).Name)
        {
        }
        #endregion

        #region *** SystemWebConfigurationIntrospectionRule ***
        protected override ProblemCollection Check(SystemWebSectionGroup webConfig)
        {
            if (webConfig == null)
                throw (new ArgumentNullException("webConfig"));

            #region Check Info
            // The rule verifies that the enableHeaderChecking is set to True.
            // Default value is true
            // ref: http://msdn.microsoft.com/en-us/library/e1f13641.aspx
            #endregion
            if (!webConfig.HttpRuntime.EnableHeaderChecking)
                AddProblem(webConfig.HttpRuntime.ElementInformation);

            return base.Problems;
        }
        #endregion
    }
}